@@ -1,3 +1,4 @@
+from pipje import pipje
 import pipje
 def showpip():
     from PIL import Image, ImageTk
@@ -5,6 +6,7 @@ def showpip():
     import tkinter as tk
     root = tk.Tk()
     root.title("Pip")
+    root.lift()
     URL = "https://i.imgur.com/1sfOxTw_d.webp?maxwidth=760&fidelity=grand"
     u = urlopen(URL)
     raw_data = u.read()
